Learn R Programming

rama (version 1.46.0)

is.row.na: Test if a matrix contains missing values

Description

The function returns a vector of logical variables, one for each row of the matrix. The variable is TRUE if the row does not contain any missing values and FAlSE otherwise.

Usage

is.row.na(data)

Arguments

data
The data matrix.

Value

  • The vector of logical variable

See Also

is.na

Examples

Run this code
### Generate a matrix
M<-matrix(rnorm(100),10,10)
M[1,1]<-NA
M[1,2]<- -Inf
M[3,10]<-NA

### Indices of the rows without missing values 
ind<-is.row.na(M)

### Submatrix of M with finite values
M.finite<-M[ind,]

Run the code above in your browser using DataLab