Learn R Programming

rama (version 1.46.0)

mat.mean: Compute the mean and standard deviation of each row in a data matrix

Description

This function computes the mean and standard deviation of each row in a data matrix. The source code is written in C. As a consequence, the computation is quite fast.

Usage

mat.mean(data)

Arguments

data
The data matrix.

Value

standard deviations.

See Also

mean,sd

Examples

Run this code
data(hiv)
sample1<-hiv[,1:4]
ms1<-mat.mean(sample1)

Run the code above in your browser using DataLab