mat.mean: Compute the mean and standard deviation of each row in a data matrix
Description
This function computes the mean and standard deviation of each row in
a data matrix. The source code is written in C. As a consequence, the
computation is quite fast.